Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/sys/dev/ic Use bus_space on sun2.
details: https://anonhg.NetBSD.org/src/rev/a7a5f04168c0
branches: trunk
changeset: 518230:a7a5f04168c0
user: fredette <fredette%NetBSD.org@localhost>
date: Mon Nov 26 20:15:48 2001 +0000
description:
Use bus_space on sun2.
Update the comment to match list of bus_space-using ports.
Removed some old unused asm() labels.
diffstat:
sys/dev/ic/ncr5380sbc.c | 6 ++----
sys/dev/ic/ncr5380var.h | 6 +++---
2 files changed, 5 insertions(+), 7 deletions(-)
diffs (61 lines):
diff -r 28cec333409a -r a7a5f04168c0 sys/dev/ic/ncr5380sbc.c
--- a/sys/dev/ic/ncr5380sbc.c Mon Nov 26 19:55:38 2001 +0000
+++ b/sys/dev/ic/ncr5380sbc.c Mon Nov 26 20:15:48 2001 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ncr5380sbc.c,v 1.46 2001/11/15 09:48:07 lukem Exp $ */
+/* $NetBSD: ncr5380sbc.c,v 1.47 2001/11/26 20:15:49 fredette Exp $ */
/*
* Copyright (c) 1995 David Jones, Gordon W. Ross
@@ -71,7 +71,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ncr5380sbc.c,v 1.46 2001/11/15 09:48:07 lukem Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ncr5380sbc.c,v 1.47 2001/11/26 20:15:49 fredette Exp $");
#include "opt_ddb.h"
@@ -2279,7 +2279,6 @@
sc->sc_prevphase = phase;
do_actions:
- __asm("_ncr5380_actions:");
if (act_flags & ACT_WAIT_DMA) {
act_flags &= ~ACT_WAIT_DMA;
@@ -2384,7 +2383,6 @@
NCR5380_WRITE(sc, sci_sel_enb, 0x80);
if ((act_flags & ACT_CMD_DONE) == 0) {
- __asm("_ncr5380_disconnected:");
NCR_TRACE("machine: discon, cur=0x%x\n", (long)sr);
}
diff -r 28cec333409a -r a7a5f04168c0 sys/dev/ic/ncr5380var.h
--- a/sys/dev/ic/ncr5380var.h Mon Nov 26 19:55:38 2001 +0000
+++ b/sys/dev/ic/ncr5380var.h Mon Nov 26 20:15:48 2001 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ncr5380var.h,v 1.21 2001/05/26 20:55:48 bjh21 Exp $ */
+/* $NetBSD: ncr5380var.h,v 1.22 2001/11/26 20:15:48 fredette Exp $ */
/*
* Copyright (c) 1995 David Jones, Gordon W. Ross
@@ -38,7 +38,7 @@
*/
/*
* Only arm26, i386, vax, mips and sparc use real bus space:
* arm32: csa driver; easy to convert
* mac68k: sbc driver; easy to convert
* pc532: ncr driver; need bus.h first
@@ -46,7 +46,7 @@
* sun3: si driver; need bus.h first
*/
#if defined(__arm26__) || defined(__i386__) || defined(__vax__) || \
- defined(__mips__) || defined(__sparc__)
+ defined(__mips__) || defined(__sparc__) || defined(sun2)
# define NCR5380_USE_BUS_SPACE
#endif
Home |
@@ -38,7 +38,7 @@
*/
/*
- * Only arm26, i386, vax, mips and sparc use real bus space:
+ * Only arm26, i386, vax, mips, sparc, and sun2 use real bus space:
* arm32: csa driver; easy to convert
* mac68k: sbc driver; easy to convert
Main Index |
Thread Index |
Old Index